summaryrefslogtreecommitdiffstats
path: root/src/groupview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/groupview.h
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/groupview.h')
-rw-r--r--src/groupview.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/src/groupview.h b/src/groupview.h
index 4ead256..40a40f9 100644
--- a/src/groupview.h
+++ b/src/groupview.h
@@ -17,8 +17,8 @@
#include "gui/listview.h"
#include "observer.h"
-#include <qdict.h>
-#include <qpixmap.h>
+#include <tqdict.h>
+#include <tqpixmap.h>
namespace Tellico {
namespace Data {
@@ -32,7 +32,7 @@ namespace Tellico {
* The GroupView shows the entries grouped, as well as the saved filters.
*
* There is one root item for each collection in the document. The entries are grouped
* by the field defined by each collection. A @ref QDict is used to keep track of the
* group items.
*
* @see Tellico::Data::Collection
@@ -41,28 +41,29 @@ namespace Tellico {
*/
class GroupView : public GUI::ListView, public Observer {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor sets up the single column, and initializes the popup menu.
*
* @param parent A pointer to the parent widget
* @param name The widget name
*/
- GroupView(QWidget* parent, const char* name=0);
+ GroupView(TQWidget* tqparent, const char* name=0);
/**
* Returns the name of the field by which the entries are grouped
*
* @return The field name
*/
- const QString& groupBy() const { return m_groupBy; }
+ const TQString& groupBy() const { return m_groupBy; }
/**
* Sets the name of the field by which the entries are grouped
*
* @param groupFieldName The field name
*/
- void setGroupField(const QString& groupFieldName);
+ void setGroupField(const TQString& groupFieldName);
/**
* Adds a collection, along with all all the groups for the collection in
* the groupFieldribute. This method gets called as well when the groupFieldribute
@@ -72,7 +73,7 @@ public:
*/
void addCollection(Data::CollPtr coll);
/**
- * Removes a root collection item, and all of its children.
+ * Removes a root collection item, and all of its tqchildren.
*
* @param coll A pointer to the collection
*/
@@ -149,21 +150,21 @@ private slots:
* @param point The location point
* @param col The column number, not currently used
*/
- void contextMenuRequested(QListViewItem* item, const QPoint& point, int col);
+ void contextMenuRequested(TQListViewItem* item, const TQPoint& point, int col);
/**
* Handles changing the icon when an item is expanded, depended on whether it refers
* to a collection, a group, or an entry.
*
* @param item A pointer to the expanded list item
*/
- void slotExpanded(QListViewItem* item);
+ void slotExpanded(TQListViewItem* item);
/**
* Handles changing the icon when an item is collapsed, depended on whether it refers
* to a collection, a group, or an entry.
*
* @param item A pointer to the collapse list item
*/
- void slotCollapsed(QListViewItem* item);
+ void slotCollapsed(TQListViewItem* item);
/**
* Filter by group
*/
@@ -182,16 +183,16 @@ private:
virtual void setSorting(int column, bool ascending = true);
void resetComparisons();
- QString groupTitle();
+ TQString groupTitle();
void updateHeader(Data::FieldPtr field=0);
bool m_notSortedYet;
Data::CollPtr m_coll;
- QDict<EntryGroupItem> m_groupDict;
- QString m_groupBy;
+ TQDict<EntryGroupItem> m_groupDict;
+ TQString m_groupBy;
- QPixmap m_groupOpenPixmap;
- QPixmap m_groupClosedPixmap;
+ TQPixmap m_groupOpenPixmap;
+ TQPixmap m_groupClosedPixmap;
};
} // end namespace
@@ -32,7 +32,7 @@ namespace Tellico {
*
* There is one root item for each collection in the document. The entries are grouped
- * by the field defined by each collection. A @ref QDict is used to keep track of the
+ * by the field defined by each collection. A @ref TQDict is used to keep track of the
* group items.
*
@@ -41,28 +41,29 @@ namespace Tellico {
* The constructor sets up the single column, and initializes the popup menu.
*
- * @param parent A pointer to the parent widget
+ * @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/